@@ -1,7 +1,7 @@
 package Aniki::Plugin::Pager;
 use 5.014002;
 
-use namespace::autoclean;
+use namespace::sweep;
 use Mouse::Role;
 
 use Carp qw/croak/;
@@ -17,7 +17,7 @@ sub select_with_pager {
 
     croak '(Aniki::Plugin::Pager#select_with_pager) `where` condition must be a reference.' unless ref $where;
 
-    my $range_condition = $self->make_range_condition($opt);
+    my $range_condition = $self->make_range_condtion($opt);
     if ($range_condition) {
         ref $where eq 'HASH'
             or croak "where condition *MUST* be HashRef when using range codition.";
