@@ -1,24 +1,24 @@
 package Aniki::Plugin::RangeConditionMaker;
 use 5.014002;
 
-use namespace::autoclean;
+use namespace::sweep;
 use Mouse::Role;
 
-use Carp qw/carp croak/;
-use SQL::QueryMaker qw/sql_gt sql_lt sql_and/;
+use Carp qw/croak/;
+use SQL::QueryMaker qw/sql_gt sql_lt/;
 
-sub make_range_condition {
+sub make_range_condtion {
     my ($self, $range) = @_;
 
     my %total_range_condition;
-    for my $type (qw/lower upper gt lt/) {
+    for my $type (qw/lower upper/) {
         next unless exists $range->{$type};
 
         ref $range->{$type} eq 'HASH'
             or croak "$type condition *MUST* be HashRef.";
 
-        my $func = $type eq 'lower' || $type eq 'gt' ? \&sql_gt
-                 : $type eq 'upper' || $type eq 'lt' ? \&sql_lt
+        my $func = $type eq 'lower' ? \&sql_gt
+                 : $type eq 'upper' ? \&sql_lt
                  : die "Unknown type: $type";
 
         my $range_condition = $range->{$type};
@@ -28,7 +28,7 @@ sub make_range_condition {
 
             my $condition = $func->($range_condition->{$column});
             $total_range_condition{$column} =
-                exists $total_range_condition{$column} ? sql_and([$total_range_condition{$column}, $condition])
+                exists $total_range_condition{$column} ? [-and => $total_range_condition{$column}, $condition]
                                                        : $condition;
         }
     }
@@ -52,7 +52,7 @@ Aniki::Plugin::RangeConditionMaker - range condition maker
     package MyDB;
     use Mouse v2.4.5;
     extends qw/Aniki/;
-    with qw/Aniki::Plugin::RangeConditionMaker/;
+    with qw/Aniki::Plugin::PagerInjector/;
 
     package main;
     my $db = MyDB->new(...);
